library(stringr)
library(dplyr)
library(survey)
library(ggplot2)

# Open data files:
setwd("c:/")

august <- as.data.frame(NULL)
augustfiles <- list.files(pattern = "^cvid_responses_2021_08_")
for(n in 1:length(augustfiles)) {
  print(as.character(n))
  temp <- read.csv(augustfiles[n], stringsAsFactors = FALSE)
  aug <- rbind(august,temp)
}

r <- read.csv("2021-07.csv.gz", stringsAsFactors=FALSE)
r <- rbind(r, aug)

# Test positive in most recent test within last 2 weeks, vaccination

v <- r[,c("fips","B10a","V1","weight")]

# B10a: 1=Tested positive, 2=Tested negative, 3=Don't know, NA=Not tested in last 2 weeks
# V1: 1=Vaccinated, 2=Not, 3=Don't know

v$Vaccinated[v$V1==1] <- 100
v$Vaccinated[v$V1!=1 & !is.na(v$V1)] <- 0

v$PercentUnvaccinated[v$V1==2] <- 100
v$PercentUnvaccinated[v$V1==1] <- 0

v$TestedPositive[v$B10a==1] <- 1000 # Tested positive in last two weeks
v$TestedPositive[v$B10a!=1 | is.na(v$B10a)] <- 0

v$InfectionRateVaccinated[v$TestedPositive==1000 & v$Vaccinated==100] <- 1000 # Tested positive in last two weeks & vaccinated
v$InfectionRateVaccinated[v$TestedPositive==0 & v$Vaccinated==100] <- 0

v$InfectionRateUnvaccinated[v$TestedPositive==1000 & v$V1==2] <- 1000 # Tested positive in last two weeks & unvaccinated
v$InfectionRateUnvaccinated[v$TestedPositive==0 & v$V1==2] <- 0

national <- v %>% 
  group_by(Vaccinated) %>% 
  summarize(NationalInfectionRate = weighted.mean(TestedPositive, weight), na.rm=TRUE)
national
national[1,2]/national[2,2]

# States

v$Numeric.code <- floor(v$fips/1000)
v$NumberOfUnvaccinatedRespondents[v$V1==2] <- 1

vstate <- v %>% 
  group_by(Numeric.code) %>% 
  summarize_at(c("PercentUnvaccinated","InfectionRateUnvaccinated","InfectionRateVaccinated"), funs(weighted.mean(., weight, na.rm=TRUE)))

vstaten <- v %>% 
  group_by(Numeric.code) %>% 
  summarize_at(c("NumberOfUnvaccinatedRespondents"), funs(sum(., na.rm=TRUE)))

vstate <- merge(vstate, vstaten, by = "Numeric.code")

statefips <- read.csv("State-FIPS-codes.csv", stringsAsFactors = FALSE)
vstate <- merge(vstate, statefips, by="Numeric.code", merge="left")
vstate[,1] <- vstate$Alpha.code
names(vstate)[1] <- "State"
vstate <- vstate[,1:5]

write.csv(vstate, "Kurzman-Breakthrough-Infections-2021-08-17.csv")

ggplot(vstate[vstate$NumberOfUnvaccinatedRespondents>=1000,], aes(x=PercentUnvaccinated, y=InfectionRateUnvaccinated, label=State)) + geom_text(size=3) + 
  geom_smooth(aes(PercentUnvaccinated, InfectionRateUnvaccinated), method='lm', se=FALSE, color="gray") +
  geom_text(aes(x=PercentUnvaccinated, y=InfectionRateVaccinated, label=State), size=3, color="red") +
  geom_smooth(aes(PercentUnvaccinated, InfectionRateVaccinated), method='lm', se=FALSE, color="red") +
  theme(panel.background=element_blank()) + theme(axis.ticks = element_blank()) +
  scale_y_continuous(breaks = seq(0,13, by=1)) + expand_limits(y = 0) + expand_limits(y = 13) +
  ylab("Positive Covid tests in previous two weeks, per 1,000 adults") +
  xlab("Percent of respondents in each state reporting they are unvaccinated") +
  annotate(geom="text", x=9, y=13, label="Covid-19 infection rates by state", hjust="left", size=5) +
  annotate(geom="text", x=9, y=11.5, label="Black: Unvaccinated respondents", hjust="left", size=3.5) +
  annotate(geom="text", x=9, y=11, label="Red: Vaccinated respondents", hjust="left", size=3.5, color="red") +
  labs(caption="\nWeighted rates from 1,422,068 adult survey respondents, July 1-August 15, 2021.\nStates with 1,000 or more unvaccinated respondents.\nCharles Kurzman, UNC-Chapel Hill, August 17, 2021.\nSurvey data: Delphi Research Group, Carnegie Mellon University.")

ggsave("Kurzman-Infection-Rates-by-State-Vaccinated-and-Unvaccinated-Respondents-2021-08-17.png", dpi=300, height=8, width=6)


# Infection rates in top 10 vaccination rates vs. lowest 10

vb <- vstate[vstate$NumberOfUnvaccinatedRespondents>=1000,]
vb <- vb[order(-vb$PercentUnvaccinated),]
dim(vb)
numberofstates <- dim(vb)[1]
numberofstatesminusnine <- numberofstates - 9

highest10v <- mean(vb$InfectionRateVaccinated[1:10])
lowest10v <- mean(vb$InfectionRateVaccinated[numberofstatesminusnine:numberofstates])
lowest10v
highest10v
highest10v/lowest10v

highest10u <- mean(vb$InfectionRateUnvaccinated[1:10])
lowest10u <- mean(vb$InfectionRateUnvaccinated[numberofstatesminusnine:numberofstates])
lowest10u
highest10u
highest10u/lowest10u

